@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2011, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.jpa.container;
@@ -27,21 +10,21 @@ import static org.jboss.as.jpa.messages.JpaLogger.ROOT_LOGGER;
 import java.util.List;
 import java.util.Map;
 
-import javax.persistence.EntityGraph;
-import javax.persistence.EntityManager;
-import javax.persistence.EntityManagerFactory;
-import javax.persistence.EntityTransaction;
-import javax.persistence.FlushModeType;
-import javax.persistence.LockModeType;
-import javax.persistence.Query;
-import javax.persistence.StoredProcedureQuery;
-import javax.persistence.SynchronizationType;
-import javax.persistence.TypedQuery;
-import javax.persistence.criteria.CriteriaBuilder;
-import javax.persistence.criteria.CriteriaDelete;
-import javax.persistence.criteria.CriteriaQuery;
-import javax.persistence.criteria.CriteriaUpdate;
-import javax.persistence.metamodel.Metamodel;
+import jakarta.persistence.EntityGraph;
+import jakarta.persistence.EntityManager;
+import jakarta.persistence.EntityManagerFactory;
+import jakarta.persistence.EntityTransaction;
+import jakarta.persistence.FlushModeType;
+import jakarta.persistence.LockModeType;
+import jakarta.persistence.Query;
+import jakarta.persistence.StoredProcedureQuery;
+import jakarta.persistence.SynchronizationType;
+import jakarta.persistence.TypedQuery;
+import jakarta.persistence.criteria.CriteriaBuilder;
+import jakarta.persistence.criteria.CriteriaDelete;
+import jakarta.persistence.criteria.CriteriaQuery;
+import jakarta.persistence.criteria.CriteriaUpdate;
+import jakarta.persistence.metamodel.Metamodel;
 import org.jboss.as.jpa.messages.JpaLogger;
 
 /**
@@ -74,7 +57,7 @@ public abstract class AbstractEntityManager implements EntityManager {
     protected abstract boolean isExtendedPersistenceContext();
 
     /**
-     * @return true if a JTA transaction is active
+     * @return true if a Jakarta Transactions transaction active
      *         <p/>
      *         Precondition: getEntityManager() must be called previous to calling isInTx
      */
@@ -840,7 +823,7 @@ public abstract class AbstractEntityManager implements EntityManager {
 
 
     // used by TransactionScopedEntityManager to auto detach loaded entities
-    // after each non-jta invocation
+    // after each non-Jakarta Transactions invocation
     protected void detachNonTxInvocation(EntityManager underlyingEntityManager) {
         if (!this.isExtendedPersistenceContext() && !this.isInTx() && !deferEntityDetachUntilClose()) {
             underlyingEntityManager.clear();
@@ -848,7 +831,7 @@ public abstract class AbstractEntityManager implements EntityManager {
     }
 
     // for JPA 2.0 section 3.8.6
-    // used by TransactionScopedEntityManager to detach entities loaded by a query in a non-jta invocation.
+    // used by TransactionScopedEntityManager to detach entities loaded by a query in a non-Jakarta Transactions invocation.
     protected Query detachQueryNonTxInvocation(EntityManager underlyingEntityManager, Query underLyingQuery) {
         if (!this.isExtendedPersistenceContext() && !this.isInTx() && !skipQueryDetach()) {
             return new QueryNonTxInvocationDetacher(underlyingEntityManager, underLyingQuery);
@@ -857,7 +840,7 @@ public abstract class AbstractEntityManager implements EntityManager {
     }
 
     // for JPA 2.0 section 3.8.6
-    // used by TransactionScopedEntityManager to detach entities loaded by a query in a non-jta invocation.
+    // used by TransactionScopedEntityManager to detach entities loaded by a query in a non-Jakarta Transactions invocation.
     protected <T> TypedQuery<T> detachTypedQueryNonTxInvocation(EntityManager underlyingEntityManager, TypedQuery<T> underLyingQuery) {
         if (!this.isExtendedPersistenceContext() && !this.isInTx() && !skipQueryDetach()) {
             return new TypedQueryNonTxInvocationDetacher<>(underlyingEntityManager, underLyingQuery);
@@ -873,7 +856,7 @@ public abstract class AbstractEntityManager implements EntityManager {
     }
 
 
-    // JPA 7.9.1 if invoked without a JTA transaction and a transaction scoped persistence context is used,
+    // JPA 7.9.1 if invoked without a Jakarta Transactions transaction and a transaction scoped persistence context is used,
     // will throw TransactionRequiredException for any calls to entity manager remove/merge/persist/refresh.
     private void transactionIsRequired() {
         if (!this.isExtendedPersistenceContext() && !this.isInTx()) {
